@@ -10,6 +10,7 @@
 #' @import stats
 #' @import TTmoment
 #' @import relliptical
+#' @import expm
 #' @description This functino fits left, right or intervalar censored mixed-effects linear model, with autoregressive errors of order \code{p}, using the EM algorithm. It returns estimates, standard errors and prediction of future observations.
 #' @param y Vector \code{1 x n} of censored responses, where \code{n} is the sum of the number of observations of each individual
 #' @param x Design matrix of the fixed effects of order \code{n x s}, corresponding to vector of fixed effects.
@@ -21,7 +22,7 @@
 #' @param order  Order of the autoregressive process. Must be a positive integer value.
 #' @param initial List with the initial values in the next orden: betas,sigma2,alphas,phi and nu. If it is not indicated it will be provided automatically. Default is \code{NULL}
 #' @param nu.fixed Logical. Should estimate the parameter "nu" for the t-student distribution?. If is False indicates the value in the list of initial values. Default is \code{FALSE}
-#' @param typeModel \code{Normal} for Normal distribution and \code{Student} for Student distribution. Default is \code{Normal}
+#' @param typeModel \code{Normal} for Normal distribution and \code{Student} for t-Student distribution. Default is \code{Normal}
 #' @param cens.type \code{left} for left censoring, \code{right} for right censoring and \code{interval} for intervalar censoring. Default is \code{left}
 #' @param LI Vector censoring lower limit indicator of length \code{n}. For each observation: \code{0} if non-censored, \code{-inf} if censored. It is only indicated for when \code{cens.type} is \code{both}. Default is \code{NULL}
 #' @param LS Vector censoring upper limit indicator of length \code{n}. For each observation: \code{0} if non-censored, \code{inf} if censored.It is only indicated for when \code{cens.type} is \code{both}. Default is \code{NULL}
@@ -39,6 +40,7 @@
 #' \item{RnEffect}{Data frame with: estimate, standar errors and confidence intervals  of the random effects.}
 #' \item{Est}{Vector of parameters estimate (fixed Effects, sigma2, phi, random effects).}
 #' \item{SE}{Vector of the standard errors of (fixed Effects, sigma2, phi, random effects).}
+#' \item{Residual}{Vector of the marginal residuals.}
 #' \item{loglik}{Log-likelihood value.}
 #' \item{AIC}{Akaike information criterion.}
 #' \item{BIC}{Bayesian information criterion.}
@@ -53,34 +55,33 @@
 #' @examples
 #' \dontrun{
 #'p.cens   = 0.1
-#'m           = 50
+#'m           = 10
 #'D = matrix(c(0.049,0.001,0.001,0.002),2,2)
 #'sigma2 = 0.30
-#'phi    = c(0.48,0.5)
+#'phi    = 0.6
 #'beta   = c(1,2,1)
-#'nj=rep(c(6,5,6,8,5,7,8,9,10,12),5)
-#'tt=rep(4,sum(nj))
+#'nj=rep(4,10)
+#'tt=rep(1:4,length(nj))
 #'x<-matrix(runif(sum(nj)*length(beta),-1,1),sum(nj),length(beta))
 #'z<-matrix(runif(sum(nj)*dim(D)[1],-1,1),sum(nj),dim(D)[1])
-#'data=ARpMMEC.sim(m,x,z,tt,nj,beta,sigma2,D,phi,p.cens)
-#'attach(data, warn.conflicts = F)
-#'Arp    = 2
-#'
-#'teste1=ARpMMEC.est(y_cc,x,z,tt,cc,nj,struc="ARp",order=1,typeModel="Normal",MaxIter = 2)
-#'teste2=ARpMMEC.est(y_cc,x,z,tt,cc,nj,struc="ARp",order=1,typeModel="Student",MaxIter = 2)
+#'data=ARpMMEC.sim(m,x,z,tt,nj,beta,sigma2,D,phi,struc="ARp",typeModel="Normal",p.cens)
+#
+#'teste1=ARpMMEC.est(data$y_cc,x,z,tt,data$cc,nj,struc="ARp",order=1,typeModel="Normal",MaxIter = 2)
+#'teste2=ARpMMEC.est(data$y_cc,x,z,tt,data$cc,nj,struc="ARp",order=1,typeModel="Student",MaxIter = 2)
 #'
 #'xx=matrix(runif(6*length(beta),-1,1),6,length(beta))
 #'zz=matrix(runif(6*dim(D)[1],-1,1),6,dim(D)[1])
 #'isubj=c(1,4,5)
-#'teste3=ARpMMEC.est(y_cc,x,z,tt,cc,nj,struc="ARp",order=1,typeModel="Normal",
-#'        MaxIter = 2,Prev=TRUE,step=2,isubj=isubj,xpre=xx,zpre=zz)
+#'teste3=ARpMMEC.est(data$y_cc,x,z,tt,data$cc,nj,struc="ARp",order=1,typeModel="Normal",
+#'                   MaxIter = 2,Prev=TRUE,step=2,isubj=isubj,xpre=xx,zpre=zz)
 #'teste3$Prev
 #'
-#'
 #' }
 #' 
 #' 
 #' @export
+#' 
+#' 
 ARpMMEC.est=function(y,x,z,tt,cc,nj,struc="UNC",order=1, initial=NULL,nu.fixed=TRUE,
                  typeModel="Normal",cens.type="left", LI=NULL,LS=NULL, MaxIter=200,
                  error=0.0001, Prev=FALSE,step=NULL,isubj=NULL,xpre=NULL,zpre=NULL)
@@ -199,20 +200,21 @@ if(!is.null(initial))
   }
   
     
-
+ 
  if(typeModel=="Normal"){
    if(struc=="ARp"){
     out<-EMCensArpN(cc=cc,y=y,x=x,z=z,tt=tt,nj=nj, Arp=order, initial=initial, cens.type=cens.type, LI=LI,LS=LS,MaxIter=MaxIter,ee=error,
         Prev=Prev,step=step,isubj=isubj ,xpre=xpre,zpre=zpre)}
    if(struc=="UNC"){
-     out<-EMCensArpN(cc=cc,y=y,x=x,z=z,tt=tt,nj=nj, Arp=struc, initial=initial, cens.type=cens.type, LI=LI,LS=LS,MaxIter=MaxIter,ee=error,
-                     Prev=Prev,step=step,isubj=isubj ,xpre=xpre,zpre=zpre)}
+    out<-EMCensArpN(cc=cc,y=y,x=x,z=z,tt=tt,nj=nj, Arp=struc, initial=initial, cens.type=cens.type, LI=LI,LS=LS,MaxIter=MaxIter,ee=error,
+        Prev=Prev,step=step,isubj=isubj ,xpre=xpre,zpre=zpre)}
    if(struc=="DEC"|struc=="DEC(AR)"|struc=="SYM"){
      out<-EMCensDECN(cc=cc,y=y,x=x,z=z,tt=tt,nj=nj, struc=struc, initial=initial, cens.type=cens.type, LI=LI,LS=LS,MaxIter=MaxIter,ee=error,
-                     Prev=Prev,step=step,isubj=isubj ,xpre=xpre,zpre=zpre)}
+        Prev=Prev,step=step,isubj=isubj ,xpre=xpre,zpre=zpre)}
  }
   
   
+
   
   if(typeModel=="Student"){
     if(struc=="ARp"){
@@ -347,7 +349,7 @@ if(!is.null(initial))
   }
  
   obj.out <- list(FixEffect=out$tableB, Sigma2=out$tableS, Phi=out$tableP,RandEffect=out$tableA,
-                  Est=c(out$beta1, sigma2=out$sigmae, phi=out$phi, RnEffect=out$dd), SE=out$SE,
+                  Est=c(out$beta1, sigma2=out$sigmae, phi=out$phi, RnEffect=out$dd), SE=out$SE,Residual=out$residual,
                   loglik=out$loglik, AIC=out$AIC, BIC=out$BIC, AICc=out$AICcorr, iter=out$iter,
                    MI=out$MI, Prev=out$Prev, time=out$time)
 
